@@ -71,3 +71,32 @@ on_about_ok_clicked (GtkButton *button, gpointer user_data)
 {
   about_dialog (FALSE);
 }
+
+gboolean
+on_gl_area_button_press_event (GtkWidget *widget,
+                               GdkEventButton *event,
+                               gpointer user_data)
+{
+  gl_button_down (widget, (void *) event);
+  return FALSE;
+}
+
+
+gboolean
+on_gl_area_button_release_event (GtkWidget *widget,
+                                 GdkEventButton *event,
+                                 gpointer user_data)
+{
+  gl_button_up (widget, (void *) event);
+  return FALSE;
+}
+
+
+gboolean
+on_gl_area_motion_notify_event (GtkWidget *widget,
+                                GdkEventMotion *event,
+                                gpointer user_data)
+{
+  gl_motion (widget, (void *) event);
+  return FALSE;
+}
