@@ -40,3 +40,18 @@ on_reset4_clicked                      (GtkButton       *button,
 void
 on_about_ok_clicked                    (GtkButton       *button,
                                         gpointer         user_data);
+
+gboolean
+on_gl_area_button_press_event          (GtkWidget       *widget,
+                                        GdkEventButton  *event,
+                                        gpointer         user_data);
+
+gboolean
+on_gl_area_button_release_event        (GtkWidget       *widget,
+                                        GdkEventButton  *event,
+                                        gpointer         user_data);
+
+gboolean
+on_gl_area_motion_notify_event         (GtkWidget       *widget,
+                                        GdkEventMotion  *event,
+                                        gpointer         user_data);
