@@ -16,6 +16,7 @@ extern const char *progname;
 
 typedef struct {
   int enabled_p;			/* whether the light is on */
+  int vector_p;				/* whether to draw a line */
   double x, y, z, w;			/* position of the light */
   struct {
     double r, g, b;			/* various light colors */
@@ -27,11 +28,17 @@ typedef struct {
   int solid_p;				/* solid, textured */
   int type;				/* teapot, cube, sphere */
 
+  int z_up_p;
+  int rotate_lights_p;
+  int spin_p;
+
   double shininess;			/* material reflectivity */
   struct {
     double r, g, b;			/* various material colors */
   } ambient, diffuse, specular;
 
+  float *mouse_quaternion;		/* mouse-driven rotation */
+
 } object_info;
 
 extern void get_light_info (int which, light_info *info_return);
@@ -41,4 +48,8 @@ extern void about_dialog (int up_p);
 extern void enable_light (int which, int enabled_p);
 extern void reset_light (int which);
 
+extern void gl_button_down (void *widget, void *event);
+extern void gl_button_up (void *widget, void *event);
+extern void gl_motion (void *widget, void *event);
+
 #endif /* __LIGHTLAB_H__ */
