@@ -14,5 +14,7 @@
 
 extern void unit_cube (int wire_p);
 extern void unit_sphere (int stacks, int slices, int wire_p);
+extern void unit_tube (int faces, int smooth, int wire);
+extern void unit_cone (int faces, int smooth, int wire);
 
 #endif /* __SPHERE_H__ */
